
#include <TGraph.h>
#include <TH3.h>
#include <TPolyLine3D.h>
#include <TCanvas.h>
#include <TLegend.h>


void mytest ( Double_t ymin=-1., Double_t ymax=-1. , Double_t zmin=-1, Double_t zmax=-1, Double_t dintensity=1e-3 )  
/// if x == -1., default value will be computed --> useful in interactive mode (zoom)
/// if x != -1., all points < or > x won't be displayed --> save plot
/// > mytest (1000.+1.,4000.-1. , -0.004,0.004)
{
	Int_t nFiles = 3 ;
	Double_t     *time       = new Double_t     [nFiles] ; 
	TString      *finName    = new TString      [nFiles] ; 
	TGraph      **g_data_raw = new TGraph*      [nFiles] , **g_data = new TGraph* [nFiles] ;  /// skimmed data (between ymin and ymax) to avoid boundaries issues
	TPolyLine3D **line3D     = new TPolyLine3D* [nFiles] ; 
	Int_t nPoints=-1 ;
	Int_t index_start=-1, index_stop=-1, index=-1 ;
	Double_t zmin_=-1., zmax_=-1. ;
	
	/// Data storage (TGraph) and limit computation
	if ( zmin == -1. ) { zmin_ = 1e20 ; } if ( zmax == -1. ) { zmax_ = -1e20 ; }
	for (Int_t ifile=0; ifile<nFiles; ifile++) {
		time      [ifile] = 3.*ifile ;
		finName   [ifile] = TString(Form("Alu_Phos_%03d.dat",ifile+1)) ;
		g_data_raw[ifile] = new TGraph(finName[ifile]) ; 
		if ( ifile == 0 ) {
			if ( ymin != -1. ) { index=0 ; while (g_data_raw[0]->GetX()[index] < ymin) { index++ ; } index_start = index ; } else { index_start = 0                       ; ymin = g_data_raw[0]->GetX()[index_start] ; }
			if ( ymax != -1. ) { index=0 ; while (g_data_raw[0]->GetX()[index] < ymax) { index++ ; } index_stop  = index ; } else { index_stop  = g_data_raw[0]->GetN()-1 ; ymax = g_data_raw[0]->GetX()[index_stop ] ; }
			nPoints = (index_stop - index_start) + 1 ;
		}
		g_data[ifile] = new TGraph (nPoints) ; for (Int_t ipoint=0; ipoint<nPoints; ipoint++) { g_data[ifile]->GetX()[ipoint] = g_data_raw[ifile]->GetX()[ipoint+index_start] ; g_data[ifile]->GetY()[ipoint] = g_data_raw[ifile]->GetY()[ipoint+index_start] ; }
		if ( zmin==-1. && g_data[ifile]->GetHistogram()->GetMinimum()<zmin_ ) { zmin_ = g_data[ifile]->GetHistogram()->GetMinimum() ; }
		if ( zmax==-1. && g_data[ifile]->GetHistogram()->GetMaximum()>zmax_ ) { zmax_ = g_data[ifile]->GetHistogram()->GetMaximum() ; }
	}
	if ( zmin == -1. ) { zmin = zmin_ ; } if ( zmax == -1. ) { zmax = zmax_ ; }

	/// TPolyLine3D filling
	for (Int_t ifile=0; ifile<nFiles; ifile++) {
		line3D    [ifile] = new TPolyLine3D (nPoints) ; 
		for (Int_t ipoint=0; ipoint<nPoints; ipoint++) { line3D[ifile]->SetPoint( ipoint, g_data[ifile]->GetX()[ipoint], time[ifile], (g_data[ifile]->GetY()[ipoint]>=zmax)? zmax : (g_data[ifile]->GetY()[ipoint]<=zmin) ? zmin : g_data[ifile]->GetY()[ipoint] ) ; } 
		line3D[ifile]->SetLineColor(ifile+2) ;
	}

	///

	TH3F* h3 = new TH3F("h3", "AluPhos - 080720", Int_t(ymax-ymin),ymin,ymax, 1,0.,time[nFiles-1], Int_t((zmax-zmin)/dintensity),zmin,zmax);
		h3->SetStats(kFALSE) ;
		h3->SetXTitle("#lambda  [nm]"    ) ; h3->GetXaxis()->CenterTitle() ; h3->GetXaxis()->SetLabelOffset(0.025) ; h3->GetXaxis()->SetTitleOffset(1.7) ; h3->GetXaxis()->SetTickLength(0.01) ; 
		h3->SetYTitle("time  [min]"      ) ; h3->GetYaxis()->CenterTitle() ; h3->GetYaxis()->SetLabelOffset(0.02 ) ; h3->GetYaxis()->SetTitleOffset(1.6) ; h3->GetYaxis()->SetTickLength(0.01) ; 
		h3->SetZTitle("intensity  [a.u.]") ; h3->GetZaxis()->CenterTitle() ; h3->GetZaxis()->SetLabelOffset(0.02 ) ; h3->GetZaxis()->SetTitleOffset(1.4) ; h3->GetZaxis()->SetTickLength(0.01) ; 

	///

	TCanvas *canvas = new TCanvas("canvas","canvas",0,0,1100,700) ; canvas->SetTheta(23.08) ; canvas->SetPhi(-22.91) ; gPad->SetLeftMargin(0.18) ; gPad->SetRightMargin(0.10) ; gPad->SetTopMargin(0.20) ; gPad->SetBottomMargin(0.20) ;
		h3->Draw("FB");
		TLegend *leg = new TLegend(0.81,0.78,0.99,0.98) ; leg->SetTextSize(0.04) ; leg->SetBorderSize(0.) ; leg->SetMargin(0.2) ; leg->SetTextFont(42) ; leg->SetFillStyle(0) ; leg->SetFillColor(kWhite) ;
		for (Int_t ifile=0; ifile<nFiles; ifile++) { line3D[ifile]->Draw() ; leg->AddEntry (line3D[ifile],TString(Form("%.0f",time[ifile])),"L") ; }
		leg->Draw() ;
	//canvas->SaveAs("mytest.png") ;

	return ; 

}
